==> paraview-5.12.1-8-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/ArrowGlyph-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel;VTK::CommonCore")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_private_depends" "ParaView::RemotingCore;VTK::CommonDataModel;VTK::FiltersCore;VTK::FiltersSources")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_library_name" "vtkArrowGlyphFilter")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkArrowGlyphFilter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkArrowGlyphFilterModule.h")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/ArrowGlyph/vtk/hierarchy/ArrowGlyph/vtkArrowGlyphFilter-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/ArrowGlyph-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel;VTK::CommonCore")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_private_depends" "ParaView::RemotingCore;VTK::CommonDataModel;VTK::FiltersCore;VTK::FiltersSources")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_library_name" "vtkArrowGlyphFilter")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkArrowGlyphFilter.h")
set_property(TARGET "ArrowGlyph::ArrowGlyphFilter" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/ArrowGlyph/vtk/hierarchy/ArrowGlyph/vtkArrowGlyphFilter-hierarchy.txt")
unset(_vtk_module_import_prefix)
